PyMEMENTO
==============================
[//]: # (Badges)
[![GitHub Actions Build Status](https://github.com/REPLACE_WITH_OWNER_ACCOUNT/PyMEMENTO/workflows/CI/badge.svg)](https://github.com/REPLACE_WITH_OWNER_ACCOUNT/PyMEMENTO/actions?query=workflow%3ACI)
[![codecov](https://codecov.io/gh/REPLACE_WITH_OWNER_ACCOUNT/PyMEMENTO/branch/master/graph/badge.svg)](https://codecov.io/gh/REPLACE_WITH_OWNER_ACCOUNT/PyMEMENTO/branch/master)


PyMEMENTO

### Copyright

Copyright (c) 2022, Simon Lichtinger


#### Acknowledgements
 
Project based on the 
[Computational Molecular Science Python Cookiecutter](https://github.com/molssi/cookiecutter-cms) version 1.6.
